/*###################################################
  # Projekt: 			FB61xx
  # Version: 			0.1
  # Erstellungsdatum: 	23.07.2007 
  # nderungsdatum:		24.07.2007
  # Autor: 				Philipp
  # Controller:			Atmega128
  ####################################################*/


/* Allgemeine Includs
*********************/
#include <avr/io.h>
#include <util/delay.h>


/* Funktionsdeklarationen
*************************/
void InitPorts(void);
void LCD_Init(void);
unsigned char LCD_Read(void);
void LCD_Write(unsigned char data);
void LCD_Control(void);
void LCD_Data(void);


/* Anschlussbelegung
********************/
//  D0 - D7		PORTA
// /RD (WR1)	PORTG.1	
// /WR (WR0)	PORTG.0
//  CD			PORTC.5
//  CS			PORTC.6
// /Reset		PORTC.7


/* Main
*******/
int main(void)
{
	unsigned char i;

	InitPorts();									// Ports initialisieren
	LCD_Init();										// LCD initialisieren

	LCD_Data();										// LCD Data Register

	PORTB |= (1<<PB6);								// Backlight an

	for (i=0; i<10; i++)							// Irgendwas aufs LCD ausgeben
	{
		LCD_Write(0xF0);
		_delay_ms(10);
	}

	return 0;
}


/* LCD initialisieren
*********************/
void LCD_Init(void)
{
	PORTC |= (1<<PC7);								// /RESET auf HIGH
	_delay_ms(200);									// 200 ms warten
	PORTC &= (1<<PC7);								// /RESET auf LOW
	_delay_ms(200);									// 200 ms warten
	PORTC |= (1<<PC7);								// /RESET auf HIGH

	LCD_Control();									// LCD Control Register

	_delay_ms(10);									// 10 ms warten
	LCD_Write(0xE2);								// System Reset

	_delay_ms(10);									// 10 ms warten
	LCD_Write(0xAF);								// Display Enable

	_delay_ms(10);									// 10 ms warten
	LCD_Write(0xA5);								// All Pixel On = TRUE
}


// Daten vom LCD lesen
unsigned char LCD_Read(void)
{
	PORTC |= (1<<PC6);								// CS auf HIGH
	PORTG |= (1<<PG0);								// /WR auf HIGH
	PORTG &= (1<<PG1);								// /RD auf LOW
	return PINA;									// data vom Bus lesen
	PORTG |= (1<<PG1);								// /RD wieder auf HIGH
	PORTC &= (1<<PC6);								// CS auf LOW
}


// Daten zum LCD senden
void LCD_Write(unsigned char data)
{
	PORTC |= (1<<PC6);								// CS auf HGH
	PORTG |= (1<<PG1);								// /RD auf HIGH
	PORTG &= (1<<PG0);								// /WR auf LOW
	PORTA = data;									// data auf den Bus schreiben
	PORTG |= (1<<PG0);								// /WR wieder auf HIGH
	PORTC &= (1<<PC6);								// CS auf LOW
}


// Setzte CD auf LOW
void LCD_Control(void)
{
	PORTC &= (1<<PC5);								// CD auf LOW
}


// Setzt CD auf HIGH
void LCD_Data(void)
{
	PORTC |= (1<<PC5);								// CD auf HIGH
}


/* Ports initialisieren
***********************/
void InitPorts(void)
{
	// Input/Output Ports initialization
	// Port A initialization
	// Func7=Out Func6=Out Func5=Out Func4=Out Func3=Out Func2=Out Func1=Out Func0=Out 
	// State7=0 State6=0 State5=0 State4=0 State3=0 State2=0 State1=0 State0=0 
	PORTA=0x00;
	DDRA=0xFF;

	// Port B initialization
	// Func7=Out Func6=Out Func5=In Func4=In Func3=In Func2=In Func1=In Func0=In 
	// State7=0 State6=0 State5=T State4=T State3=T State2=T State1=T State0=T 
	PORTB=0x00;
	DDRB=0xC0;

	// Port C initialization
	// Func7=Out Func6=Out Func5=Out Func4=In Func3=In Func2=In Func1=In Func0=In 
	// State7=0 State6=0 State5=0 State4=T State3=T State2=T State1=T State0=T 
	PORTC=0x00;
	DDRC=0xE0;

	// Port D initialization
	// Func7=In Func6=In Func5=In Func4=In Func3=Out Func2=In Func1=In Func0=In 
	// State7=T State6=T State5=T State4=T State3=0 State2=T State1=T State0=T 
	PORTD=0x00;
	DDRD=0x08;

	// Port E initialization
	// Func7=In Func6=In Func5=In Func4=In Func3=Out Func2=In Func1=In Func0=In 
	// State7=T State6=T State5=T State4=T State3=0 State2=T State1=T State0=T 
	PORTE=0x00;
	DDRE=0x08;

	// Port F initialization
	// Func7=In Func6=Out Func5=In Func4=In Func3=In Func2=In Func1=In Func0=In 
	// State7=T State6=0 State5=T State4=T State3=T State2=T State1=T State0=T 
	PORTF=0x00;
	DDRF=0x40;

	// Port G initialization
	// Func4=In Func3=In Func2=In Func1=Out Func0=Out 
	// State4=T State3=T State2=T State1=1 State0=1 
	PORTG=0x03;
	DDRG=0x03;
}
